@@ -23,13 +23,13 @@ class Config:
             self._create_config()
 
     @property
-    def anipy_cli_folder(self):
+    def _anipy_cli_folder(self):
         return Path(Path(__file__).parent)
 
     @property
     def download_folder_path(self):
         return self._get_path_value(
-            "download_folder_path", self.anipy_cli_folder / "download"
+            "download_folder_path", self._anipy_cli_folder / "download"
         )
 
     @property
@@ -41,7 +41,7 @@ class Config:
     @property
     def user_files_path(self):
         return self._get_path_value(
-            "user_files_path", self.anipy_cli_folder / "user_files"
+            "user_files_path", self._anipy_cli_folder / "user_files"
         )
 
     @property
@@ -62,11 +62,11 @@ class Config:
 
     @property
     def mpv_commandline_options(self):
-        return self._get_value("mpv_cmd_options", [], list)
+        return self._get_value("mpv_commandline_options", [], list)
 
     @property
     def vlc_commandline_options(self):
-        return self._get_value("vlc_cmd_options", [], list)
+        return self._get_value("vlc_commandline_options", [], list)
 
     @property
     def reuse_mpv_window(self):
@@ -97,7 +97,7 @@ class Config:
     def _get_path_value(self, key: str, fallback: Path) -> Path:
         path = self._get_value(key, fallback, str)
         try:
-            return Path(path)
+            return Path(path).expanduser()
         except:
             return fallback
 
